##  Mapping Relations
After configuring how you want to map fact sheets to ServiceNow tables—or vice versa—you can also map relations between those fact sheets or records to the other system. For details, see [Relation Mapping Between ServiceNow and SAP LeanIX](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Map relations between records in ServiceNow and fact sheets in SAP LeanIX.").
YesNo
Send
